@@ -1,6 +1,6 @@
 # -*- coding: iso-8859-1 -*-
 # Copyright (C) 2004-2005 Tristan Seligmann and Jonathan Jacobs
-# Copyright (C) 2012-2013 Bastian Kleineidam
+# Copyright (C) 2012-2014 Bastian Kleineidam
 
 from re import compile, escape
 
@@ -18,6 +18,15 @@ class Caggage(_BasicScraper):
     prevSearch = compile(tagre("a", "href", r'(%sarchives/\d+)' % rurl, after="prev"))
     help = 'Index format: number'
 
+class CampComic(_BasicScraper):
+    url = 'http://campcomic.com/comic/'
+    rurl = escape(url)
+    stripUrl = url + '%s'
+    firstStripUrl = stripUrl % '6'
+    imageSearch = compile(tagre("img", "src", r'(http://hw1\.pa-cdn\.com/camp/assets/img/katie/comics/[^"]+)'))
+    prevSearch = compile(tagre("a", "href", r'(%s[^"]+)' % rurl, before="btn btnPrev"))
+    help = 'Index Format: number'
+    description = u'Camp Weedonwantcha is a place where kids get dropped off for the summer and are never picked up again.'
 
 class CaptainSNES(_BasicScraper):
     description = u'Captain SNES'
@@ -191,24 +200,6 @@ class Chisuji(_BasicScraper):
     help = 'Index format: yyyy/mm/dd/strip-name'
 
 
-class ChugworthAcademy(_BasicScraper):
-    url = 'http://chugworth.com/'
-    stripUrl = url + '?p=%s'
-    firstStripUrl = stripUrl % '12'
-    imageSearch = compile(r'<img src="(.+?)" alt="Comic')
-    prevSearch = compile(r'<a href="(http://chugworth.com/\?p=\d{1,4})"[^>]+?title="Previous">')
-    help = 'Index format: n (unpadded)'
-
-
-class ChugworthAcademyArchive(_BasicScraper):
-    url = 'http://chugworth.com/archive/?strip_id=422'
-    stripUrl = 'http://chugworth.com/archive/?strip_id=%s'
-    firstStripUrl = stripUrl % '0'
-    imageSearch = compile(r'<img src=(comics/\d+.+?.\w{1,4})')
-    prevSearch = compile(r'<a href=\'(.+?)\'><img src=\'images/previous.gif')
-    help = 'Index format: nnn'
-
-
 class CigarroAndCerveja(_BasicScraper):
     description = u'Cigarro & Cerveja'
     url = 'http://www.cigarro.ca/'
@@ -435,10 +426,13 @@ class CyanideAndHappiness(_BasicScraper):
             self.stripUrl % "3360", # video
             self.stripUrl % "3367", # video
             self.stripUrl % "3382", # video
+            self.stripUrl % "3421", # video
         )
 
     @classmethod
     def namer(cls, imageUrl, pageUrl):
         imgname = imageUrl.split('/')[-1]
+        # only get the first 100 chars for the image name
+        imgname = imgname[:100]
         imgnum = pageUrl.split('/')[-2]
         return '%s_%s' % (imgnum, imgname)
