@@ -1,6 +1,6 @@
 # -*- coding: iso-8859-1 -*-
 # Copyright (C) 2004-2005 Tristan Seligmann and Jonathan Jacobs
-# Copyright (C) 2012-2013 Bastian Kleineidam
+# Copyright (C) 2012-2014 Bastian Kleineidam
 
 from re import compile, escape
 from ..scraper import _BasicScraper
@@ -120,6 +120,12 @@ class PHDComics(_BasicScraper):
         tagre("img", "src", r'(?:comics/)?images/prev_button\.gif', quote=""))
     help = 'Index format: number'
 
+    def shouldSkipUrl(self, url):
+        """Skip pages without images."""
+        return url in (
+            self.stripUrl % '1669', # video
+        )
+
 
 class PicPakDog(_BasicScraper):
     description = u'A comic by Kim Belding'
@@ -189,6 +195,17 @@ class PokeyThePenguin(_BasicScraper):
         return "%s/index%d.html" % (prefix, num)
 
 
+class PoorlyDrawnLines(_BasicScraper):
+    url = 'http://poorlydrawnlines.com/comic/'
+    rurl = escape(url)
+    stripUrl = url + '%s'
+    firstStripUrl = stripUrl % 'campus-characters/'
+    imageSearch = compile(tagre("img", "src", r'(http://poorlydrawnlines\.com/wp-content/uploads/\d+/\d+/[^"]+)'))
+    prevSearch = compile(tagre("li", "class", r'previous') + tagre("a", "href", r'(%s[^"]+)' % rurl))
+    help = 'Index Format: name'
+    description = u'A thrice-weekly webcomic written and illustrated by Reza Farazmand. New comics every Monday, Wednesday, and Friday.'
+
+
 class Precocious(_BasicScraper):
     url = 'http://www.precociouscomic.com/'
     starter = indirectStarter(url,
