@@ -1,6 +1,6 @@
 # -*- coding: iso-8859-1 -*-
 # Copyright (C) 2004-2005 Tristan Seligmann and Jonathan Jacobs
-# Copyright (C) 2012-2013 Bastian Kleineidam
+# Copyright (C) 2012-2014 Bastian Kleineidam
 
 from re import compile, escape, IGNORECASE, sub
 from os.path import splitext
@@ -79,6 +79,16 @@ class SandraOnTheRocks(_BasicScraper):
     prevSearch = compile(tagre("a", "href", r'([^"]*/strips-sotr/[^"]+)', before="cn[id]prev"))
     help = 'Index format: name'
 
+class ScandinaviaAndTheWorld(_BasicScraper):
+    description = u'Scandinavia and the World'
+    url = 'http://satwcomic.com/'
+    rurl = escape(url)
+    stripUrl = url + '%s/'
+    firstStripUrl = stripUrl % 'sweden-denmark-and-norway'
+    imageSearch = compile(tagre("img", "src", r'(%sart/[^"/]+)' % rurl))
+    prevSearch = compile(tagre("a", "href", r'(%s[^"/]+)' % rurl)+"\s*"+tagre('span', 'class', 'spritePrevious'))
+    help = 'Index format: stripname'
+
 class ScaryGoRound(_BasicScraper):
     url = 'http://www.scarygoround.com/'
     stripUrl = url + '?date=%s'
@@ -449,6 +459,17 @@ class SPQRBlues(_BasicScraper):
     help = 'Index format: number'
 
 
+class StandStillStaySilent(_BasicScraper):
+    url = 'http://www.sssscomic.com/comic.php'
+    rurl = escape(url)
+    stripUrl = url + '?page=%s'
+    firstStripUrl = stripUrl % '1'
+    imageSearch = compile(tagre("img", "src", r"(comicpages/[^']+)", before="comicnormal", quote="'"))
+    prevSearch = compile(tagre("a", "href", r"([^']+)", quote="'") + tagre("div", "id", r'navprev', quote="'"))
+    help = 'Index Format: number'
+    description = u'"Stand Still. Stay Silent" is a post-apocalyptic adventure story with a rather light tone and careless pace.'
+
+
 # XXX disallowed by robots.txt
 class _StationV3(_BasicScraper):
     url = 'http://www.stationv3.com/'
